Enum arducam_mega::CaptureFormat
source · #[repr(u8)]
pub enum CaptureFormat {
Jpeg,
Rgb,
Yuv,
}Expand description
The format in which the camera data should be formatted
You will most likely want to use Jpeg, as Rgb generates images that are much greater in
size than Jpeg, and could therefore data blobs that are too big for your MCU to handle.
Variants