Enum arducam_mega::CaptureResolution
source · #[repr(u8)]
pub enum CaptureResolution {
Show 13 variants
Qqvga,
Qvga,
Vga,
Svga,
Hd,
Sxgam,
Uxga,
Fhd,
Qxga,
Wqxga2,
Res96x96,
Res128x128,
Res320x320,
}Expand description
The resolution of the image captured by the camera
Qvga and Vga are good test values. Qqvga is listed in the SDK, however is also not
explicitly added to the camera’s supported resolutions. Qqvga is therefore listed here but
hasn’t been tested.
If both the 3mp and 5mp features are enabled, this enum will have a Fhd (1080p) default,
as that is the highest resolution compatible with both cameras. When only the 3mp feature is
enabled, the enum will default to the camera’s maximum supported resolution: Qxga. When only
the 5mp feature is enabled, the enum will default to Wqxga2.
Variants
Qqvga
QQVGA resolution (160x120). Untested, and the official Arducam SDK does not list this resolution as supported by either the 3MP or 5MP Arducam Mega.
Qvga
QVGA resolution (320x240). Untested.
Vga
VGA resolution (640x480). Tested on the Ardumcam Mega 5MP.
Svga
SVGA resolution (800x600). Untested.
Hd
HD resolution (1280x720). Untested.
Sxgam
SXGAM resolution (1280x960). Untested.
Uxga
UXGA resolution (1600x1200). Untested.
Fhd
FHD resolution (1920x1080). Untested. This is the default choice for this enum when both
the 3mp and 5mp features are enabled.
Qxga
3mp only.QXGA resolution (2048x1536). Untested. This is the default choice for this enum when the
3mp feature (only) is enabled.
Wqxga2
5mp only.WQXGA2 resolution (2592x1944). Untested. This is the default choice for this enum when the
5mp feature (only) is enabled.
Res96x96
96x96 resolution. Untested.
Res128x128
128x128 resolution. Untested.
Res320x320
320x320 resolution. Untested.